import type { DateRange } from '../dateRange'
import type { EntryTagCollection } from '../entryTag'
import type { ListWithEntries } from './shared'

/**
 * This describes aditional information about a blog entry
 * to display when listing the entry on the blog-list page.
 * At minimum, the title should be specified.
 */
export type BlogEntry = {
  /**
   * Specifies the date of the blog entry
   */
  date?: DateRange | string | number
  /**[Supports Markdown]
   * Information to summarize an entry
   */
  description?: string
  /**
   * Tags that correspond to filters on the blog-list page if defined
   */
  tags?: string[]
  /**[Supports Markdown]
   * The title of the blog entry
   */
  title: string
  /**
   * Information regarding the thumbnail
   */
  thumbnail?: {
    /**
     * Sets the inline-styles for the thumbnail
     */
    style: CSSStyleDeclaration
  }
  /**
   * URL to the markdown document of the blog entry
   */
  url: string
}

export type BlogList = {
  tags?: EntryTagCollection
  removeFromView?: boolean
} & ListWithEntries<BlogEntry>
