/**
 * Defines entries that are already fetched or are embedded directly in the list.
 * Stored in key-value format where the key is the id of the entry,
 * and the value is the entry config itself
 * (defined as `T` based on the type of the entries in the implemented list)
 */
export type ListEntries<T> = { [key: string]: T }

/**
 * Defines entries that are fetched from remote config files.
 * Stored in key-value format where the key is the id of the entry,
 * and the value is the url to the config file.
 */
export type ListRemoteEntries = { [key: string]: string }

/**
 * Defines a list-type template that has config entries defined by id.
 * One of two must be defined: `entries` or `embeddedEntries`.
 * Both can be defined and used simultaneously.
 * Note that in the case of an `id` collision
 * (i.e. both `entries` and `embeddedEntries` have an entry with the same id),
 * the implemented behavior should pick the `embeddedEntry`
 */
export type ListWithEntries<T> = {
  /**
   * Entries that will be fetched from remote config files
   */
  entries?: ListRemoteEntries
  /**
   * Entries that are embedded directly in the list config
   */
  embeddedEntries?: ListEntries<T>
}

export type ListEntriesWithNestedEntries<T> = { [key: string]: T & ListWithEntries<T> }

export type ListWithNestedEntries<T> = {
  entries?: ListRemoteEntries
  embeddedEntries?: ListEntriesWithNestedEntries<T>
}
